@@ -1,21 +1,19 @@
-/* $Header: /cvsroot/nco/nco/src/nco++/ncap2.cc,v 1.189 2014/03/25 14:19:36 hmb Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco++/ncap2.cc,v 1.194 2014/08/11 11:41:26 hmb Exp $ */
 
 /* ncap2 -- netCDF arithmetic processor */
 
 /* Purpose: Compute user-defined derived fields using forward algebraic notation applied to netCDF files */
 
 /* Copyright (C) 1995--2014 Charlie Zender
-   
-   License: GNU General Public License (GPL) Version 3
-   The full license text is at http://www.gnu.org/copyleft/gpl.html 
-   and in the file nco/doc/LICENSE in the NCO source distribution.
-   
+   This file is part of NCO, the netCDF Operators. NCO is free software.
+   You can redistribute and/or modify NCO under the terms of the 
+   GNU General Public License (GPL) Version 3.
    As a special exception to the terms of the GPL, you are permitted 
    to link the NCO source code with the HDF, netCDF, OPeNDAP, and UDUnits
    libraries and to distribute the resulting executables under the terms 
    of the GPL, but in addition obeying the extra stipulations of the 
    HDF, netCDF, OPeNDAP, and UDUnits licenses.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
@@ -72,9 +70,8 @@
 
 /* 3rd party vendors */
 #ifdef ENABLE_GSL
-#include <gsl/gsl_errno.h>
-#include <gsl/gsl_rng.h>
-
+# include <gsl/gsl_errno.h>
+# include <gsl/gsl_rng.h>
 #endif // !ENABLE_GSL
 
 /* Personal headers */
@@ -125,6 +122,8 @@ main(int argc,char **argv)
   nco_bool WRT_TMP_FL=True; /* [flg] Write output to temporary file */
   nco_bool flg_cln=True; /* [flg] Clean memory prior to exit */
   
+  aed_sct att_item; // Used to convert atts in vector to normal form  
+  
   char **fl_lst_abb=NULL_CEWI; /* Option n */
   char **fl_lst_in;
   char **var_lst_in=NULL_CEWI;
@@ -145,8 +144,8 @@ main(int argc,char **argv)
   char *spt_arg[NCAP_SPT_NBR_MAX]; /* fxm: Arbitrary size, should be dynamic */
   char *spt_arg_cat=NULL_CEWI; /* [sng] User-specified script */
   
-  const char * const CVS_Id="$Id: ncap2.cc,v 1.189 2014/03/25 14:19:36 hmb Exp $"; 
-  const char * const CVS_Revision="$Revision: 1.189 $";
+  const char * const CVS_Id="$Id: ncap2.cc,v 1.194 2014/08/11 11:41:26 hmb Exp $"; 
+  const char * const CVS_Revision="$Revision: 1.194 $";
   const char * const att_nm_tmp="eulaVlliF_"; /* For netCDF4 name hack */
   const char * const opt_sht_lst="3467ACcD:FfhL:l:n:Oo:p:Rrs:S:t:vx-:"; /* [sng] Single letter command line options */
   
@@ -223,8 +222,6 @@ main(int argc,char **argv)
   var_sct **var_prc;
   var_sct **var_prc_out;
   
-  aed_sct att_item; // Used to convert atts in vector to normal form  
-  
   static struct option opt_lng[]=
     { /* Structure ordered by short option key if possible */
       /* Long options with no argument, no short option counterpart */
@@ -401,6 +398,7 @@ main(int argc,char **argv)
     case 'D': /* Debugging level. Default is 0. */
       nco_dbg_lvl=(unsigned short int)strtoul(optarg,&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
       if(*sng_cnv_rcd) nco_sng_cnv_err(optarg,"strtoul",sng_cnv_rcd);
+      nc_set_log_level(nco_dbg_lvl);
       break;
     case 'F': /* Toggle index convention. Default is 0-based arrays (C-style). */
       FORTRAN_IDX_CNV=!FORTRAN_IDX_CNV;
@@ -521,8 +519,8 @@ main(int argc,char **argv)
   bil_cls bil_obj(true); 
   // Co-ordinates functions
   cod_cls cod_obj(true); 
-
-
+  // misc functions
+  misc_cls misc_obj(true); 
 
   // Populate vector
   (void)pop_fmc_vtr(fmc_vtr,&cnv_obj);
@@ -539,6 +537,7 @@ main(int argc,char **argv)
   (void)pop_fmc_vtr(fmc_vtr,&arr_obj);
   (void)pop_fmc_vtr(fmc_vtr,&bil_obj);
   (void)pop_fmc_vtr(fmc_vtr,&cod_obj);
+  (void)pop_fmc_vtr(fmc_vtr,&misc_obj);
 
 #ifdef ENABLE_GSL
 #ifdef ENABLE_NCO_GSL
@@ -738,6 +737,7 @@ main(int argc,char **argv)
     xtr_lst_a=nco_var_lst_mk(out_id,nbr_var_fl,(char**)NULL,False,False,&nbr_xtr);      
     for(idx=0;idx<nbr_var_fl;idx++){
       var_tmp=prs_arg.ncap_var_init(xtr_lst_a[idx].nm,false);
+
       Nvar=new NcapVar(var_tmp); 
       Nvar->flg_stt=2;   
       prs_arg.var_vtr.push(Nvar);
@@ -877,7 +877,7 @@ main(int argc,char **argv)
   /* Define non-processed vars */
   (void)nco_var_dfn(in_id,fl_out,out_id,var_out,xtr_nbr,(dmn_sct **)NULL,(int)0,nco_pck_plc_nil,nco_pck_map_nil,dfl_lvl);
   
-  /* Write out new attributes possibly overwriting old ones */
+  /* Write new attributes possibly overwriting old ones */
   for(idx=0;idx<var_vtr.size();idx++){
    
     if(var_vtr[idx]->xpr_typ == ncap_var){
@@ -887,35 +887,34 @@ main(int argc,char **argv)
       var_ref=var_vtr[idx]->var;
       rcd=nco_inq_varid_flg(out_id,var_ref->nm,&var_id);
       
-      /* filter out ram vars */ 
+      /* Filter-out RAM vars */ 
       if(rcd!=NC_NOERR || !var_ref->has_mss_val) continue;  
       
-      /* see if missing value already present */
+      /* Is missing value already present? */
       rcd_inq_att=nco_inq_att_flg(out_id,var_id,nco_mss_val_sng_get(),&att_item.type,&att_item.sz);
 
-      /* type mismatch dont overwrite. This can occur when packed vars are in output from using the -A switch */
-      if(rcd_inq_att==NC_NOERR && var_ref->type != att_item.type) continue;   
+      /* Do not overwrite if type mismatch, e.g., packed variable are in output with -A switch */
+      if(rcd_inq_att == NC_NOERR && var_ref->type != att_item.type) continue;   
 
-      /* fill mode and att exists */ 
-      if(prs_arg.NCAP4_FILL && rcd_inq_att==NC_NOERR){
+      /* Fill-mode and attribute exists */ 
+      if(prs_arg.NCAP4_FILL && rcd_inq_att == NC_NOERR){
         (void)nco_rename_att(out_id,var_id,nco_mss_val_sng_get(),att_nm_tmp);     
         (void)nco_put_att(out_id,var_id,att_nm_tmp,var_ref->type,1,var_ref->mss_val.vp);   
         (void)nco_rename_att(out_id,var_id,att_nm_tmp,nco_mss_val_sng_get());  
         continue;
-      }
+      } /* end if */
 
-      /* fill mode and att doesn't exist   */ 
-      if(prs_arg.NCAP4_FILL && rcd_inq_att!=NC_NOERR){
+      /* Fill-mode and attribute does not exist   */ 
+      if(prs_arg.NCAP4_FILL && rcd_inq_att != NC_NOERR){
         (void)nco_put_att(out_id,var_id,att_nm_tmp,var_ref->type,1,var_ref->mss_val.vp);
         (void)nco_rename_att(out_id,var_id,att_nm_tmp,nco_mss_val_sng_get());
         continue;
-      }
+      } /* end if */
 
-      /* netcdf3 file just put att */
+      /* netCDF3 file so just put attribute */
       (void)nco_put_att(out_id,var_id,nco_mss_val_sng_get(),var_ref->type,1,var_ref->mss_val.vp);      
       continue;
-    }
-   
+    } /* endif */
 
      /* Write misssing value contained inside variable */
      /* If missing value type is same as disk type  */  
@@ -958,15 +957,15 @@ main(int argc,char **argv)
     /* NB: These attributes should probably be written prior to last data mode */
     (void)nco_aed_prc(out_id,var_id,att_item);
     
- cln_up: ;
-   att_item.var_nm=(char*)nco_free(att_item.var_nm);
-   att_item.att_nm=(char*)nco_free(att_item.att_nm);
+  cln_up:
+    att_item.var_nm=(char*)nco_free(att_item.var_nm);
+    att_item.att_nm=(char*)nco_free(att_item.att_nm);
   } /* end for */
   
   /* Set chunksize parameters */
   if(fl_out_fmt == NC_FORMAT_NETCDF4 || fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC) (void)nco_cnk_sz_set(out_id,(lmt_msa_sct **)NULL_CEWI,(int)0,&cnk_map,&cnk_plc,cnk_sz_scl,cnk.cnk_dmn,cnk_nbr);
 
-  /* Turn off default filling behavior to enhance efficiency */
+  /* Turn-off default filling behavior to enhance efficiency */
   nco_set_fill(out_id,NC_NOFILL,&fll_md_old);
   
   /* Take output file out of define mode */
