@@ -1,10 +1,11 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco.h,v 1.510 2014/05/27 03:26:18 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco.h,v 1.514 2014/07/07 06:04:22 zender Exp $ */
 
 /* Purpose: netCDF Operator (NCO) definitions */
 
 /* Copyright (C) 1995--2014 Charlie Zender
-   License: GNU General Public License (GPL) Version 3
-   See http://www.gnu.org/copyleft/gpl.html for full license text */
+   This file is part of NCO, the netCDF Operators. NCO is free software.
+   You can redistribute and/or modify NCO under the terms of the 
+   GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 /* Usage:
    #include "nco.h" *//* netCDF Operator (NCO) definitions */
@@ -240,9 +241,25 @@ extern "C" {
 /* Compatibility tokens for when NCO compiled with older netcdf.h
    It is hard to track where/when many tokens defined
    Easiest to individually check for pre-definition of each */
-/* Three compatibility tokens new to netCDF4 netcdf.h: */
+/* Compatibility tokens new to netCDF4 netcdf.h: */
 #ifndef NC_NETCDF4
-# define NC_NETCDF4     (0x1000) /* Use netCDF-4/HDF5 format */
+# define NC_NETCDF4  0x1000 /* Use netCDF-4/HDF5 format. Mode flag for nc_create(). */
+#endif
+#ifndef NC_MPIIO
+# define NC_MPIIO    0x2000 /* Turn on MPI I/O. Mode flag for both nc_create() and nc_open(). */
+#endif
+#ifndef NC_MPIPOSIX
+# define NC_MPIPOSIX 0x4000 /* Turn on MPI POSIX I/O. Mode flag for both nc_create() and nc_open(). */
+#endif
+#ifndef NC_PNETCDF
+# define NC_PNETCDF  0x8000 /* Use parallel-netcdf library. Mode flag for nc_open(). */
+#endif
+/* Use these with nc_var_par_access(). */
+#ifndef NC_INDEPENDENT
+# define NC_INDEPENDENT 0
+#endif
+#ifndef NC_COLLECTIVE
+# define NC_COLLECTIVE 1
 #endif
 #ifndef NC_ENDIAN_NATIVE
 # define NC_ENDIAN_NATIVE 0
@@ -313,6 +330,18 @@ extern "C" {
 #endif
 #ifndef NC_FORMAT_DAP4
 # define NC_FORMAT_DAP4    (6)
+#endif
+
+  /* Three compatibility tokens from pnetcdf.h introduced to NCO 20140604 
+     None are used yet */
+#ifndef NC_64BIT_DATA
+# define NC_64BIT_DATA	0x0010 /* CDF-5 format, (64-bit) supported */
+#endif
+#ifndef NC_FORMAT_CDF5
+# define NC_FORMAT_CDF5  5 /* CDF-5 format, with NC_64BIT_DATA. */
+#endif
+#ifndef NC_FORMAT_64BIT_DATA
+# define NC_FORMAT_64BIT_DATA	NC_FORMAT_CDF5
 #endif
 
   /* Backwards-compatibility error codes for netCDF4
