@@ -1,10 +1,11 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.c,v 1.122 2014/05/20 05:53:20 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.c,v 1.128 2014/08/22 01:01:21 zender Exp $ */
 
 /* Purpose: NCO utilities for chunking */
 
 /* Copyright (C) 1995--2014 Charlie Zender
-   License: GNU General Public License (GPL) Version 3
-   See http://www.gnu.org/copyleft/gpl.html for full license text */
+   This file is part of NCO, the netCDF Operators. NCO is free software.
+   You can redistribute and/or modify NCO under the terms of the 
+   GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 /* Usage:
    ncks -O -4 -D 4 --cnk_scl=8 ~/nco/data/in.nc ~/foo.nc
@@ -85,6 +86,8 @@ nco_cnk_plc_sng_get /* [fnc] Convert chunking policy enum to string */
     return "g2d";
   case nco_cnk_plc_g3d: 
     return "g3d";
+  case nco_cnk_plc_r1d:
+    return "r1d";
   case nco_cnk_plc_xpl: 
     return "xpl";
   case nco_cnk_plc_xst:
@@ -181,9 +184,18 @@ nco_cnk_ini /* [fnc] Create structure with all chunking information */
   /* Make uniform list of user-specified per-dimension chunksizes */
   if(cnk->cnk_nbr > 0) cnk->cnk_dmn=nco_cnk_prs(cnk_nbr,cnk_arg);
 
-  /* Set actual chunk policy and map to defaults as necessary */
-  if(cnk_map == nco_cnk_map_nil) cnk->cnk_map=nco_cnk_map_get((char *)NULL);
-  if(cnk_plc == nco_cnk_plc_nil) cnk->cnk_plc=nco_cnk_plc_get((char *)NULL);
+  /* Set actual chunk policy and map to defaults as necessary
+     20140821: Until today, defaults for map and policy were set independently
+     Now we consider four distinct cases: 
+     1. Neither map nor policy was explicitly set, and something else, e.g., size, was
+     2. User set map not policy
+     3. User set policy not map */
+  if(cnk->flg_usr_rqs && (cnk_map == nco_cnk_map_nil) && (cnk_plc == nco_cnk_plc_nil)){
+    cnk->cnk_map=nco_cnk_map_rd1;
+    cnk->cnk_plc=nco_cnk_plc_g2d;
+  } /* endif */
+  if(cnk_map == nco_cnk_map_nil && cnk_plc != nco_cnk_plc_nil) cnk->cnk_map=nco_cnk_map_rd1;
+  if(cnk_plc == nco_cnk_plc_nil && cnk_map != nco_cnk_map_nil) cnk->cnk_plc=nco_cnk_plc_g2d;
 
   return rcd;
 } /* end nco_cnk_ini() */
@@ -294,14 +306,15 @@ nco_cnk_map_get /* [fnc] Convert user-specified chunking map to key */
 (const char *nco_cnk_map_sng) /* [sng] User-specified chunking map */
 {
   /* Purpose: Convert user-specified string to chunking map
-     Return nco_cnk_map_rd1 by default */
+     Return nco_cnk_map_xst by default */
   const char fnc_nm[]="nco_cnk_map_get()"; /* [sng] Function name */
   char *nco_prg_nm; /* [sng] Program name */
   nco_prg_nm=nco_prg_nm_get(); /* [sng] Program name */
 
   if(nco_cnk_map_sng == NULL){
-    if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stdout,"%s: INFO %s reports %s invoked without explicit chunking map. Defaulting to chunking map \"rd1\".\n",nco_prg_nm,fnc_nm,nco_prg_nm);
-    return nco_cnk_map_rd1;
+    /* 20140815: Change default from rd1 to xst */
+    if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stdout,"%s: INFO %s reports %s invoked without explicit chunking map. Defaulting to chunking map \"xst\".\n",nco_prg_nm,fnc_nm,nco_prg_nm);
+    return nco_cnk_map_xst;
   } /* endif */
 
   if(!strcmp(nco_cnk_map_sng,"nil")) return nco_cnk_map_nil;
@@ -331,14 +344,15 @@ nco_cnk_plc_get /* [fnc] Convert user-specified chunking policy to key */
 (const char *nco_cnk_plc_sng) /* [sng] User-specified chunking policy */
 {
   /* Purpose: Convert user-specified string to chunking operation type 
-     Return nco_cnk_plc_g2d by default */
+     Return nco_cnk_plc_xst by default */
   const char fnc_nm[]="nco_cnk_plc_get()"; /* [sng] Function name */
   char *nco_prg_nm; /* [sng] Program name */
   nco_prg_nm=nco_prg_nm_get(); /* [sng] Program name */
 
   if(nco_cnk_plc_sng == NULL){
-    if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stdout,"%s: INFO %s reports %s invoked without explicit chunking policy. Defaulting to chunking policy \"g2d\".\n",nco_prg_nm,fnc_nm,nco_prg_nm);
-    return nco_cnk_plc_g2d;
+    /* 20140815: Change default from g2d to xst */
+    if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stdout,"%s: INFO %s reports %s invoked without explicit chunking policy. Defaulting to chunking policy \"xst\".\n",nco_prg_nm,fnc_nm,nco_prg_nm);
+    return nco_cnk_plc_xst;
   } /* endif */
 
   if(!strcmp(nco_cnk_plc_sng,"nil")) return nco_cnk_plc_nil;
@@ -354,6 +368,9 @@ nco_cnk_plc_get /* [fnc] Convert user-specified chunking policy to key */
   if(!strcmp(nco_cnk_plc_sng,"cnk_g3d")) return nco_cnk_plc_g3d;
   if(!strcmp(nco_cnk_plc_sng,"plc_g3d")) return nco_cnk_plc_g3d;
   if(!strcmp(nco_cnk_plc_sng,"xpl")) return nco_cnk_plc_xpl;
+  if(!strcmp(nco_cnk_plc_sng,"r1d")) return nco_cnk_plc_r1d;
+  if(!strcmp(nco_cnk_plc_sng,"cnk_r1d")) return nco_cnk_plc_r1d;
+  if(!strcmp(nco_cnk_plc_sng,"plc_r1d")) return nco_cnk_plc_r1d;
   if(!strcmp(nco_cnk_plc_sng,"cnk_xpl")) return nco_cnk_plc_xpl;
   if(!strcmp(nco_cnk_plc_sng,"plc_xpl")) return nco_cnk_plc_xpl;
   if(!strcmp(nco_cnk_plc_sng,"xst")) return nco_cnk_plc_xst;
@@ -791,6 +808,7 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
   nc_type var_typ_dsk; /* [nbr] Variable type */
 
   nco_bool *flg_mch; /* [flg] Name match (absolute or relative) between chunking structure 'cnk_sct' and dimension 'dmn_cmn' */
+  nco_bool flg_ovr; /* [flg] Override default chunking with user-specified chunking for this dimension */
   nco_bool flg_usr_rqs; /* [flg] User requested checking */
   nco_bool is_rec_var; /* [flg] Record variable */
   nco_bool is_chk_var; /* [flg] Check-summed variable */
@@ -861,7 +879,7 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
   is_chunked=False; /* [flg] Chunked variable */
   is_xpl_cnk=False; /* [flg] Explicitly chunked variable */
 
-  /* Obtain variable ID using group ID */
+  /* Obtain variable ID */
   (void)nco_inq_varid(grp_id_out,var_nm,&var_id_out);
   (void)nco_inq_varid(grp_id_in,var_nm,&var_id_in);
 
@@ -909,7 +927,7 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
     /* Some variables simply must be chunked */
     if(nco_dbg_lvl_get() >= nco_dbg_var && nco_dbg_lvl_get() != nco_dbg_dev) (void)fprintf(stdout,"%s: INFO %s %s must be chunked (record, compressed, or check-summed variable)\n",nco_prg_nm_get(),fnc_nm,var_nm);
   }else{
-    /* Explicitly turn-off chunking for arrays that are... */
+    /* Explicitly exit this chunking function now (and thus implement netCDF4-default chunking behavior) for variables that are... */
     if((cnk_plc == nco_cnk_plc_xpl && !is_xpl_cnk) || /* ...not explicitly chunked... */
        (cnk_plc == nco_cnk_plc_xst && !is_chunked) || /* ...not already chunked... */
        (cnk_plc == nco_cnk_plc_g2d && dmn_nbr < 2) || /* ...much too small... */
@@ -1095,11 +1113,13 @@ cnk_xpl_override: /* end goto */
 
   /* Override "reasonable" defaults with explicitly set per-dimension sizes, if any */
   flg_mch=(nco_bool *)nco_malloc(dmn_nbr*sizeof(nco_bool));
+  /* Loop over all dimensions in this variable */
   for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++){
 
     /* Initialize to false then override */
     flg_mch[dmn_idx]=False;
 
+    /* Loop over all user-specified chunk-sizes */
     for(cnk_idx=0;cnk_idx<cnk_nbr;cnk_idx++){
 
       if(cnk_dmn[cnk_idx]->nm_fll){
@@ -1108,32 +1128,49 @@ cnk_xpl_override: /* end goto */
         if(!strcmp(cnk_dmn[cnk_idx]->nm,dmn_cmn[dmn_idx].nm)) flg_mch[dmn_idx]=True;
       } /* end else */
 
-      /* Name match found */
+      /* User-specified name matches current dimension name */
       if(flg_mch[dmn_idx]){
-        cnk_sz[dmn_idx]=cnk_dmn[cnk_idx]->sz;
-        /* Is this a record dimension? */
-        if(dmn_cmn[dmn_idx].is_rec_dmn){
-          /* dmn_sz of record dimension can/will be zero in output file
-	     Allow (though warn) when cnk_sz > dmn_sz in such cases */
-          if(dmn_cmn[dmn_idx].NON_HYP_DMN){
-            if(dmn_cmn[dmn_idx].sz > 0 && /* Warn only after records have been written */
-	       cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].sz){
-              (void)fprintf(stderr,"%s: WARNING %s allowing user-specified record dimension %s chunksize %lu which exceeds current output file record dimension size = %lu. May fail if output file is not concatenated from multiple inputs.\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].sz);
-            } /* endif too big */
-          }else{ /* !NON_HYP_DMN */
-            if(cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].dmn_cnt){
-              (void)fprintf(stderr,"%s: WARNING %s allowing user-specified record dimension %s chunksize = %lu which exceeds user-specified record dimension input hyperslab size = %lu. May fail if output file is not concatenated from multiple inputs.\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].dmn_cnt);
-            } /* endif too big */
-          } /* !NON_HYP_DMN */
-        }else{ /* !rcd_dmn_id */
-          if(cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].sz){
-            /* Unlike record dimensions, non-record dimensions must have cnk_sz <= dmn_sz */
-            (void)fprintf(stderr,"%s: WARNING %s trimming user-specified fixed dimension %s chunksize from %lu to %lu\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].sz);
-            /* Trim else out-of-bounds sizes will fail in HDF library in nc_enddef() */
-            cnk_sz[dmn_idx]=(size_t)dmn_cmn[dmn_idx].sz;
-          } /* endif */
-        } /* !rcd_dmn_id */
-        break;
+	flg_ovr=False;
+
+	/* Override default chunking with user-specified chunking for this dimension if... */
+	if(
+	   /* ... Policy is anything but r1d or ...*/
+	   (cnk_plc != nco_cnk_plc_r1d) ||
+	   /* ... Policy is r1d and this is the matching r1d coordinate or ... */
+	   (cnk_plc == nco_cnk_plc_r1d && (dmn_nbr == 1 && is_rec_var)) ||
+	   False){
+	  /* Perform override */
+	  cnk_sz[dmn_idx]=cnk_dmn[cnk_idx]->sz;
+	  flg_ovr=True;
+	} /* endif */
+
+	/* Sanity checks for dimensions that were over-ridden by user-specified chunksizes */
+	if(flg_ovr){
+	  /* Is this a record dimension? */
+	  if(dmn_cmn[dmn_idx].is_rec_dmn){
+	    /* dmn_sz of record dimension can/will be zero in output file
+	       Allow (though warn) when cnk_sz > dmn_sz in such cases */
+	    if(dmn_cmn[dmn_idx].NON_HYP_DMN){
+	      if(dmn_cmn[dmn_idx].sz > 0 && /* Warn only after records have been written */
+		 cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].sz){
+		(void)fprintf(stderr,"%s: WARNING %s allowing user-specified record dimension %s chunksize %lu which exceeds current output file record dimension size = %lu. May fail if output file is not concatenated from multiple inputs.\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].sz);
+	      } /* endif too big */
+	    }else{ /* !NON_HYP_DMN */
+	      if(cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].dmn_cnt){
+		(void)fprintf(stderr,"%s: WARNING %s allowing user-specified record dimension %s chunksize = %lu which exceeds user-specified record dimension input hyperslab size = %lu. May fail if output file is not concatenated from multiple inputs.\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].dmn_cnt);
+	      } /* endif too big */
+	    } /* !NON_HYP_DMN */
+	  }else{ /* !rcd_dmn_id */
+	    if(cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].sz){
+	      /* Unlike record dimensions, non-record dimensions must have cnk_sz <= dmn_sz */
+	      (void)fprintf(stderr,"%s: WARNING %s trimming user-specified fixed dimension %s chunksize from %lu to %lu\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].sz);
+	      /* Trim else out-of-bounds sizes will fail in HDF library in nc_enddef() */
+	      cnk_sz[dmn_idx]=(size_t)dmn_cmn[dmn_idx].sz;
+	    } /* endif */
+	  } /* !rcd_dmn_id */
+	} /* !flg_ovr */
+	/* Dimension matched this chunk name, no need to search other chunk names */
+	break;
       } /* cnk_nm != dmn_nm */
     } /* end loop over dimensions */
   } /* end loop over cnk */
