@@ -1,10 +1,11 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_fl_utl.c,v 1.240 2014/05/22 15:40:34 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_fl_utl.c,v 1.249 2014/08/22 20:27:48 zender Exp $ */
 
 /* Purpose: File manipulation */
 
 /* Copyright (C) 1995--2014 Charlie Zender
-   License: GNU General Public License (GPL) Version 3
-   See http://www.gnu.org/copyleft/gpl.html for full license text */
+   This file is part of NCO, the netCDF Operators. NCO is free software.
+   You can redistribute and/or modify NCO under the terms of the 
+   GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 #include "nco_fl_utl.h" /* File manipulation */
 
@@ -33,6 +34,8 @@ nco_create_mode_mrg /* [fnc] Merge clobber mode with user-specified file format
   md_create=md_clobber;
   if(fl_out_fmt == NC_FORMAT_64BIT){
     md_create|=NC_64BIT_OFFSET;
+  }else if(fl_out_fmt == NC_FORMAT_CDF5){
+    md_create|=NC_64BIT_DATA;
   }else if(fl_out_fmt == NC_FORMAT_NETCDF4){
     md_create|=NC_NETCDF4;
   }else if(fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC){
@@ -44,6 +47,10 @@ nco_create_mode_mrg /* [fnc] Merge clobber mode with user-specified file format
     nco_exit(EXIT_FAILURE);
   } /* end else fl_out_fmt */
 
+#ifdef ENABLE_MPI
+  md_create|=NC_NETCDF4|NC_MPIIO;
+#endif /* !ENABLE_MPI */
+
   return md_create;
 } /* end nco_create_mode_mrg() */
 
@@ -54,7 +61,9 @@ nco_create_mode_prs /* [fnc] Parse user-specified file format */
 {
   int rcd=NC_NOERR; /* [rcd] Return code */
 
-  /* Careful! Some valid format strings are subsets of other valid format strings */
+  /* Careful! Some valid format strings are subsets of other valid format strings:
+     "classic" is a sub-string of itself and of "netcdf4_classic"
+     "netcdf4" is a sub-string of itself and of "netcdf4_classic" */
   if(strcasestr("classic",fl_fmt_sng) && !strcasestr(fl_fmt_sng,"netcdf4")){
     /* If "classic" contains string and string does not contain "netcdf4" */
     *fl_fmt_enm=NC_FORMAT_CLASSIC;
@@ -75,13 +84,13 @@ nco_create_mode_prs /* [fnc] Parse user-specified file format */
     (void)fprintf(stderr,"%s: ERROR This NCO was not built with netCDF4 and cannot create the requested netCDF4 file format. HINT: Re-try with netCDF3 file format, either by omitting the filetype specification, or by explicitly specifying the \"-3\", \"--fl_fmt=classic\", \"-6\",  or \"--fl_fmt=64bit\" options.\n",nco_prg_nm_get());
     nco_exit(EXIT_FAILURE);
 #endif /* !ENABLE_NETCDF4 */
-  }else if(strcasestr("znetcdf",fl_fmt_sng)){
-#ifdef ENABLE_ZNETCDF
-    /* If "znetcdf" contains string */
-    *fl_fmt_enm=NC_COMPRESS;
-#else /* !ENABLE_ZNETCDF */
-    (void)fprintf(stderr,"%s: ERROR This NCO was not built with znetCDF (http://snow.cit.cornell.edu/noon/z_netcdf.html) and cannot create the requested znetCDF file format. HINT: Re-try with different (or no) specified file format, such as \"classic\" or \"64bit\".\n",nco_prg_nm_get());
-#endif /* !ENABLE_ZNETCDF */
+  }else if(strcasestr("pnetcdf",fl_fmt_sng)){
+#ifdef ENABLE_MPI
+    /* If "pnetcdf" contains string */
+    *fl_fmt_enm=NC_FORMAT_CDF5;
+#else /* !ENABLE_MPI */
+    (void)fprintf(stderr,"%s: ERROR This NCO was not built with PnetCDF (http://trac.mcs.anl.gov/projects/parallel-netcdf) and cannot create the requested PnetCDF file format. HINT: Re-try with supported file format such as \"classic\" or \"64bit\".\n",nco_prg_nm_get());
+#endif /* !ENABLE_MPI */
   }else{
     (void)fprintf(stderr,"%s: ERROR Unknown output file format \"%s\" requested. Valid formats are (unambiguous leading characters of) \"classic\", \"64bit\", \"netcdf4\", and \"netcdf4_classic\".\n",nco_prg_nm_get(),fl_fmt_sng);
     nco_exit(EXIT_FAILURE);
@@ -233,8 +242,8 @@ nco_fl_cp /* [fnc] Copy first file to second */
 
   /* 20131227 Allow for whitespace characters in fl_dst 
      Assume CDL translation results in acceptable name for shell commands */
-  fl_src_cdl=nm2sng_cdl(fl_src);
-  fl_dst_cdl=nm2sng_cdl(fl_dst);
+  fl_src_cdl=nm2sng_fl(fl_src);
+  fl_dst_cdl=nm2sng_fl(fl_dst);
 
   /* Construct and execute copy command */
   cmd_cp=(char *)nco_malloc((strlen(cmd_cp_fmt)+strlen(fl_src_cdl)+strlen(fl_dst_cdl)-fmt_chr_nbr+1UL)*sizeof(char));
@@ -415,9 +424,10 @@ nco_fl_lst_mk /* [fnc] Create file list from command line positional arguments *
 	} /* endelse */
 
 	/* Allocate temporary space for input buffer */
-#define FL_NM_IN_MAX_LNG 256 /* [nbr] Maximum length of input file name */
-#define FL_LST_IN_MAX_LNG 10000000 /* [nbr] Maximum length of input file list */
-	/* 20121207: 10 MB is per user request of S. McGinnis on 20121130 */
+#define FL_NM_IN_MAX_LNG 256 /* [nbr] Maximum length of single input file name */
+#define FL_LST_IN_MAX_LNG 504576001 /* [nbr] Maximum length of input file list */
+	/* 20121207: 10 MB per request of S. McGinnis 20121130
+	   20140711: 50 MB per request of Christine Smit 20140711 for 30 years of hourly data files each 192 characters long */
 	bfr_in=(char *)nco_malloc((FL_NM_IN_MAX_LNG+1L)*sizeof(char));
 	(void)sprintf(fmt_sng,"%%%ds\n",FL_NM_IN_MAX_LNG);
 
@@ -532,6 +542,7 @@ nco_fl_mk_lcl /* [fnc] Retrieve input file and return local filename */
   const char fnc_nm[]="nco_fl_mk_lcl()"; /* [sng] Function name */
   const char ftp_url_sng[]="ftp://";
   const char http_url_sng[]="http://";
+  const char https_url_sng[]="https://";
   const char sftp_url_sng[]="sftp://";
 
 #ifdef ENABLE_DAP
@@ -571,8 +582,8 @@ nco_fl_mk_lcl /* [fnc] Retrieve input file and return local filename */
     fl_nm_lcl=(char *)nco_malloc(strlen(fl_pth_lcl_tmp)+1UL);
     (void)strcpy(fl_nm_lcl,fl_pth_lcl_tmp);
     fl_nm_lcl_tmp=(char *)nco_free(fl_nm_lcl_tmp);
-  }else if(strstr(fl_nm_lcl,http_url_sng) == fl_nm_lcl){
-    /* Filename starts with "http://": Try DAP first (if available), then wget */
+  }else if((strstr(fl_nm_lcl,http_url_sng) == fl_nm_lcl) || (strstr(fl_nm_lcl,https_url_sng) == fl_nm_lcl)){
+    /* Filename starts with "http://" or "https://" so try DAP first (if available), then wget */
 
 #ifdef ENABLE_DAP
     /* Filename has http:// prefix so try DAP access to unadulterated filename */
@@ -1161,8 +1172,8 @@ nco_fl_mv /* [fnc] Move first file to second */
 
   /* 20131227 Allow for whitespace characters in fl_dst 
      Assume CDL translation results in acceptable name for shell commands */
-  fl_src_cdl=nm2sng_cdl(fl_src);
-  fl_dst_cdl=nm2sng_cdl(fl_dst);
+  fl_src_cdl=nm2sng_fl(fl_src);
+  fl_dst_cdl=nm2sng_fl(fl_dst);
 
   /* Construct and execute move command */
   cmd_mv=(char *)nco_malloc((strlen(cmd_mv_fmt)+strlen(fl_src_cdl)+strlen(fl_dst_cdl)-fmt_chr_nbr+1UL)*sizeof(char));
@@ -1364,8 +1375,12 @@ nco_fl_open /* [fnc] Open file using appropriate buffer size hints and verbosity
   if(flg_rqs_vrb_xpl) (void)fprintf(stderr,"%s: INFO %s reports nc__open() will request file buffer size = %lu bytes\n",nco_prg_nm_get(),fnc_nm,(unsigned long)*bfr_sz_hnt); 
 
   /* Pass local copy of size hint otherwise user-specified value is overwritten on first call */
+#ifdef ENABLE_MPI
+  rcd=nco_open_par(fl_nm,md_open|NC_MPIIO,MPI_COMM_WORLD,MPI_INFO_NULL,nc_id);
+#else /* !ENABLE_MPI */
   rcd=nco__open(fl_nm,md_open,&bfr_sz_hnt_lcl,nc_id);
-  
+#endif /* !ENABLE_MPI */
+
   /* Print results using same verbosity criteria
      NB: bfr_sz_hnt_lcl is never NULL because nco__open() always returns a valid size */
   if(flg_rqs_vrb_mpl || flg_rqs_vrb_xpl) (void)fprintf(stderr,"%s: INFO %s reports nc__open() opened file with buffer size = %lu bytes\n",nco_prg_nm_get(),fnc_nm,(unsigned long)bfr_sz_hnt_lcl);
@@ -1568,7 +1583,11 @@ nco_fl_out_open /* [fnc] Open output file subject to availability and user input
   bfr_sz_hnt_lcl= (bfr_sz_hnt) ? *bfr_sz_hnt : NC_SIZEHINT_DEFAULT; /* [B] Buffer size hint */
 
   if(FORCE_OVERWRITE){
+#ifdef ENABLE_MPI
+    rcd+=nco_create_par(fl_out_tmp,md_create,MPI_COMM_WORLD,MPI_INFO_NULL,out_id);
+#else /* !ENABLE_MPI */
     rcd+=nco__create(fl_out_tmp,md_create,NC_SIZEHINT_DEFAULT,&bfr_sz_hnt_lcl,out_id);
+#endif /* !ENABLE_MPI */
     return fl_out_tmp;
   } /* end if */
 
@@ -1654,8 +1673,12 @@ nco_fl_out_open /* [fnc] Open output file subject to availability and user input
       break;
     case 'O':
     case 'o':
-      rcd+=nco__create(fl_out_tmp,md_create,NC_SIZEHINT_DEFAULT,&bfr_sz_hnt_lcl,out_id);
-      break;
+#ifdef ENABLE_MPI
+    rcd+=nco_create_par(fl_out_tmp,md_create,MPI_COMM_WORLD,MPI_INFO_NULL,out_id);
+#else /* !ENABLE_MPI */
+    rcd+=nco__create(fl_out_tmp,md_create,NC_SIZEHINT_DEFAULT,&bfr_sz_hnt_lcl,out_id);
+#endif /* !ENABLE_MPI */
+       break;
     case 'A':
     case 'a':
       /* Incur expense of copying current file to temporary file */
@@ -1670,7 +1693,11 @@ nco_fl_out_open /* [fnc] Open output file subject to availability and user input
     md_create=NC_NOCLOBBER;
     md_create=nco_create_mode_mrg(md_create,fl_out_fmt);
     if(RAM_CREATE) md_create|=NC_DISKLESS|NC_WRITE;
+#ifdef ENABLE_MPI
+    rcd+=nco_create_par(fl_out_tmp,md_create,MPI_COMM_WORLD,MPI_INFO_NULL,out_id);
+#else /* !ENABLE_MPI */
     rcd+=nco__create(fl_out_tmp,md_create,NC_SIZEHINT_DEFAULT,&bfr_sz_hnt_lcl,out_id);
+#endif /* !ENABLE_MPI */
   } /* end if output file does not already exist */
 
   if(rcd != NC_NOERR) nco_err_exit(rcd,fnc_nm);
