@@ -1,10 +1,11 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_utl.h,v 1.511 2014/05/21 20:39:29 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_utl.h,v 1.514 2014/08/26 17:53:43 pvicente Exp $ */
 
 /* Purpose: Group utilities */
 
-/* Copyright (C) 2011--2014 Charlie Zender
-   License: GNU General Public License (GPL) Version 3
-   See http://www.gnu.org/copyleft/gpl.html for full license text */
+/* Copyright (C) 1995--2014 Charlie Zender
+   This file is part of NCO, the netCDF Operators. NCO is free software.
+   You can redistribute and/or modify NCO under the terms of the 
+   GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 /* Usage:
    #include "nco_var_utl.h" *//* Group utilities */
@@ -671,9 +672,9 @@ nco_dmn_swap                           /* [fnc] Swap dimensions */
 
 void
 nco_dfn_dmn                            /* [fnc] Define dimension size and ID in array */
-(const char * const dmn_nm,            /* I [sng] Name of dimension */
+(const char * const dmn_nm_fll_out,    /* I [sng] Full name of dimension in output */
  const long dmn_sz,                    /* I [nbr] Size of dimension */
- const int dmn_id,                     /* I [id] ID of dimension */
+ const int dmn_id_out,                 /* I [id] ID of dimension in output */
  dmn_cmn_sct *dmn_cmn,                 /* I/O [sct] Dimension structure array */
  const int nbr_dmn);                   /* I [nbr] Number of dimensions (size of above array) */
 
@@ -725,11 +726,6 @@ nco_lmt_aux                           /* [fnc] Apply auxiliary -X limits (Auxili
  const int idx_dmn,                   /* I [nbr] Dimension index */
  trv_tbl_sct * const trv_tbl);        /* I/O [sct] GTT (Group Traversal Table) */
 
-void
-nco_prn_var                           /* [fnc] Print variable (debug only) */
-(const int nc_id,                     /* I [ID] netCDF file ID (Input or output file) */
- trv_tbl_sct * const trv_tbl);        /* I/O [sct] Traversal table */
-
 void
 nco_dmn_lmt                            /* [fnc] Convert a lmt_sct array to dmn_sct (name only) */
 (lmt_sct **lmt,                        /* I [lst] lmt_sct array  */
@@ -737,8 +733,7 @@ nco_dmn_lmt                            /* [fnc] Convert a lmt_sct array to dmn_s
  dmn_sct ***dmn);                      /* O [sct] dmn_sct array  */
 
 void
-nco_prn_nsm                           /* [fnc] Print ensembles  */                                
-(const trv_tbl_sct * const trv_tbl);  /* I [sct] Traversal table */
+nco_prn_nsm                           /* [fnc] Print ensembles  */                       (const trv_tbl_sct * const trv_tbl);  /* I [sct] Traversal table */
 
 void
 nco_bld_nsm                           /* [fnc] Build ensembles */
