@@ -1,10 +1,11 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_msa.c,v 1.246 2014/05/23 20:37:23 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_msa.c,v 1.250 2014/08/27 04:44:01 zender Exp $ */
 
 /* Purpose: Multi-slabbing algorithm */
 
 /* Copyright (C) 1995--2014 Charlie Zender
-   License: GNU General Public License (GPL) Version 3
-   See http://www.gnu.org/copyleft/gpl.html for full license text */
+   This file is part of NCO, the netCDF Operators. NCO is free software.
+   You can redistribute and/or modify NCO under the terms of the 
+   GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 #include "nco_msa.h" /* Multi-slabbing algorithm */
 
@@ -780,10 +781,7 @@ nco_msa_wrp_splt_trv   /* [fnc] Split wrapped dimensions (GTT version) */
 
     if(dmn_trv->lmt_msa.lmt_dmn[idx]->srt > dmn_trv->lmt_msa.lmt_dmn[idx]->end){
 
-      if(nco_dbg_lvl_get() == nco_dbg_old){
-        (void)fprintf(stdout,"%s: INFO %s dimension <%s> has wrapped limits (%li->%li):\n",
-          nco_prg_nm_get(),fnc_nm,dmn_trv->nm_fll,dmn_trv->lmt_msa.lmt_dmn[idx]->srt,dmn_trv->lmt_msa.lmt_dmn[idx]->end);
-      }
+      if(nco_dbg_lvl_get() == nco_dbg_old) (void)fprintf(stdout,"%s: INFO %s dimension <%s> has wrapped limits (%li->%li):\n",nco_prg_nm_get(),fnc_nm,dmn_trv->nm_fll,dmn_trv->lmt_msa.lmt_dmn[idx]->srt,dmn_trv->lmt_msa.lmt_dmn[idx]->end);
 
       lmt_wrp=(lmt_sct *)nco_malloc(2*sizeof(lmt_sct));
 
@@ -831,7 +829,6 @@ nco_msa_wrp_splt_trv   /* [fnc] Split wrapped dimensions (GTT version) */
         (void)fprintf(stdout,"%d:\n",dmn_trv->lmt_msa.lmt_dmn_nbr);
       }
 
-
       /* "trv": Insert 2 non-wrapped limits */ 
 
       /* Current number of dimension limits for this table dimension  */
@@ -859,19 +856,13 @@ nco_msa_wrp_splt_trv   /* [fnc] Split wrapped dimensions (GTT version) */
       /* Update current index of dimension limits for this table dimension  */
       dmn_trv->lmt_msa.lmt_crr++;
 
-      if(nco_dbg_lvl_get() == nco_dbg_old){
-        (void)fprintf(stdout,"%s: INFO %s dimension <%s> new limits inserted (%li->%li) - (%li->%li):\n",
-          nco_prg_nm_get(),fnc_nm,dmn_trv->nm_fll,dmn_trv->lmt_msa.lmt_dmn[idx]->srt,dmn_trv->lmt_msa.lmt_dmn[idx]->end,
-          dmn_trv->lmt_msa.lmt_dmn[lmt_new_idx]->srt,dmn_trv->lmt_msa.lmt_dmn[lmt_new_idx]->end);
-      }
+      if(nco_dbg_lvl_get() == nco_dbg_old) (void)fprintf(stdout,"%s: INFO %s dimension <%s> new limits inserted (%li->%li) - (%li->%li):\n",nco_prg_nm_get(),fnc_nm,dmn_trv->nm_fll,dmn_trv->lmt_msa.lmt_dmn[idx]->srt,dmn_trv->lmt_msa.lmt_dmn[idx]->end,dmn_trv->lmt_msa.lmt_dmn[lmt_new_idx]->srt,dmn_trv->lmt_msa.lmt_dmn[lmt_new_idx]->end);
 
     } /* endif srt > end */
   } /* end loop over size */
 
   /* Check if genuine wrapped co-ordinate */
-  if(size==1 && dmn_trv->lmt_msa.lmt_dmn_nbr==2){
-    dmn_trv->lmt_msa.WRP=True;
-  }
+  if(size == 1 && dmn_trv->lmt_msa.lmt_dmn_nbr == 2) dmn_trv->lmt_msa.WRP=True;
 
 } /* End nco_msa_wrp_splt_trv() */
 
@@ -921,7 +912,6 @@ nco_msa_clc_cnt_trv     /* [fnc] Calculate size of  multiple hyperslab (GTT vers
   } /* end else */
 
   return; 
-
 } /* End nco_msa_clc_cnt_trv() */
 
 void             
@@ -942,8 +932,6 @@ nco_msa_qsort_srt_trv  /* [fnc] Sort limits by srt values (GTT version) */
 
 } /* End nco_msa_qsort_srt_trv() */
 
-
-
 nco_bool                /* O [flg] Return true if limits overlap (GTT version) */
 nco_msa_ovl_trv         /* [fnc] See if limits overlap */ 
 (dmn_trv_sct *dmn_trv)  /* [sct] Dimension structure from GTT */
@@ -1030,7 +1018,6 @@ nco_msa_wrp_splt /* [fnc] Split wrapped dimensions */
   if(size==1 && lmt_lst->lmt_dmn_nbr==2) lmt_lst->WRP=True;
 } /* end nco_msa_wrp_splt() */
 
-
 void
 nco_msa_wrp_splt_cpy    /* [fnc] Split wrapped dimensions (make deep copy of new wrapped limits) */
 (lmt_msa_sct *lmt_lst)  /* [sct] MSA */
@@ -1113,7 +1100,6 @@ nco_msa_wrp_splt_cpy    /* [fnc] Split wrapped dimensions (make deep copy of new
         (void)fprintf(stdout,"current limits=%d:\n",lmt_lst->lmt_dmn_nbr);
       }
 
-
       /* "trv": Insert 2 non-wrapped limits */ 
 
       /* Current number of dimension limits for this table dimension  */
@@ -1141,11 +1127,7 @@ nco_msa_wrp_splt_cpy    /* [fnc] Split wrapped dimensions (make deep copy of new
       /* Update current index of dimension limits for this table dimension  */
       lmt_lst->lmt_crr++;
 
-      if(nco_dbg_lvl_get() == nco_dbg_old){
-        (void)fprintf(stdout,"%s: INFO %s dimension <%s> new limits inserted (%li->%li) - (%li->%li):\n",
-          nco_prg_nm_get(),fnc_nm,lmt_lst->dmn_nm,lmt_lst->lmt_dmn[idx]->srt,lmt_lst->lmt_dmn[idx]->end,
-          lmt_lst->lmt_dmn[lmt_new_idx]->srt,lmt_lst->lmt_dmn[lmt_new_idx]->end);
-      }
+      if(nco_dbg_lvl_get() == nco_dbg_old) (void)fprintf(stdout,"%s: INFO %s dimension <%s> new limits inserted (%li->%li) - (%li->%li):\n",nco_prg_nm_get(),fnc_nm,lmt_lst->dmn_nm,lmt_lst->lmt_dmn[idx]->srt,lmt_lst->lmt_dmn[idx]->end,lmt_lst->lmt_dmn[lmt_new_idx]->srt,lmt_lst->lmt_dmn[lmt_new_idx]->end);
 
     } /* endif srt > end */
   } /* end loop over size */
@@ -1165,7 +1147,8 @@ nco_cpy_var_val_mlt_lmt_trv         /* [fnc] Copy variable data from input to ou
 {
   /* Purpose: Copy variable data from input netCDF file to output netCDF file 
      Routine truncates dimensions in variable definition in output file according to user-specified limits
-     Routine copies variable-by-variable, old-style, used only by ncks 
+     Routine copies variable-by-variable, old-style, used only by ncks
+     Routine does not handle strides (srd)
 
      "GTT" changes from the original nco_cpy_var_val_mlt_lmt():
      Object to write (variable) is passed as parameter */
@@ -1367,9 +1350,8 @@ nco_cpy_msa_lmt                     /* [fnc] Copy MSA struct from table to local
 
       } /* End Loop needed limits */
 
-
       /* No limits? ...Make a limit to read all */
-      if ( (*lmt_msa)[dmn_idx_var]->lmt_dmn_nbr == 0){
+      if ((*lmt_msa)[dmn_idx_var]->lmt_dmn_nbr == 0){
 
         if(nco_dbg_lvl_get() == nco_dbg_old) (void)fprintf(stdout,"Warning...no limit zone\n "); 
 
@@ -1382,9 +1364,9 @@ nco_cpy_msa_lmt                     /* [fnc] Copy MSA struct from table to local
         (void)nco_lmt_init((*lmt_msa)[dmn_idx_var]->lmt_dmn[0]);
 
         /* And set start,count,stride to read everything ...major success */
-        (*lmt_msa)[dmn_idx_var]->lmt_dmn[0]->srt=0;
+        (*lmt_msa)[dmn_idx_var]->lmt_dmn[0]->srt=0L;
         (*lmt_msa)[dmn_idx_var]->lmt_dmn[0]->cnt=(*lmt_msa)[dmn_idx_var]->dmn_sz_org;
-        (*lmt_msa)[dmn_idx_var]->lmt_dmn[0]->srd=1;
+        (*lmt_msa)[dmn_idx_var]->lmt_dmn[0]->srd=1L;
 
       } /* Make a limit to read all */
     } /* If there are limits for this variable dimension, get MSA from table */
@@ -1436,9 +1418,9 @@ nco_cpy_msa_lmt                     /* [fnc] Copy MSA struct from table to local
         (void)nco_lmt_init((*lmt_msa)[dmn_idx_var]->lmt_dmn[0]);
 
         /* And set start,count,stride to read everything ...major success */
-        (*lmt_msa)[dmn_idx_var]->lmt_dmn[0]->srt=0;
+        (*lmt_msa)[dmn_idx_var]->lmt_dmn[0]->srt=0L;
         (*lmt_msa)[dmn_idx_var]->lmt_dmn[0]->cnt=(*lmt_msa)[dmn_idx_var]->dmn_sz_org;
-        (*lmt_msa)[dmn_idx_var]->lmt_dmn[0]->srd=1;
+        (*lmt_msa)[dmn_idx_var]->lmt_dmn[0]->srd=1L;
 
       } /* Make a limit to read all */
     } /* If there are limits for this variable dimension, get MSA from table */
@@ -1476,7 +1458,7 @@ nco_msa_var_get_trv                 /* [fnc] Get variable data from disk taking
   var_trv=trv_tbl_var_nm_fll(var_in->nm_fll,trv_tbl);
   assert(var_trv);
 
-  /* Obtain group ID using full group name */
+  /* Obtain group ID */
   (void)nco_inq_grp_full_ncid(nc_id,var_trv->grp_nm_fll,&grp_id);
 
   nbr_dim=var_in->nbr_dim;	
