@@ -1,10 +1,11 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_netcdf.h,v 1.114 2014/04/14 04:54:12 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_netcdf.h,v 1.120 2014/07/10 23:36:22 zender Exp $ */
 
 /* Purpose: NCO wrappers for netCDF C library */
 
 /* Copyright (C) 1995--2014 Charlie Zender
-   License: GNU General Public License (GPL) Version 3
-   See http://www.gnu.org/copyleft/gpl.html for full license text */
+   This file is part of NCO, the netCDF Operators. NCO is free software.
+   You can redistribute and/or modify NCO under the terms of the 
+   GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 /* Usage:
 #include "nco_netcdf.h" *//* NCO wrappers for netCDF C library */
@@ -47,10 +48,10 @@
 
 /* 3rd party vendors */
 #include <netcdf.h> /* netCDF definitions and C library */
-#ifdef ENABLE_PNETCDF
-#include <mpi.h> /* MPI definitions */
-#include <pnetcdf.h> /* ANL Parallel netCDF definitions and C library */
-#endif /* !ENABLE_PNETCDF */
+#ifdef ENABLE_MPI
+# include <mpi.h> /* MPI definitions */
+# include <netcdf_par.h> /* Parallel netCDF definitions */
+#endif /* !ENABLE_MPI */
 
 /* Personal headers */
 #include "nco_typ.h" /* Type definitions, opaque types */
@@ -114,6 +115,18 @@
 # define NC_FORMAT_DAP4    (6)
 #endif
 
+/* Three compatibility tokens from pnetcdf.h introduced to NCO 20140604 
+   None are used yet */
+#ifndef NC_64BIT_DATA
+# define NC_64BIT_DATA	0x0010 /* CDF-5 format, (64-bit) supported */
+#endif
+#ifndef NC_FORMAT_CDF5
+# define NC_FORMAT_CDF5  5 /* CDF-5 format, with NC_64BIT_DATA. */
+#endif
+#ifndef NC_FORMAT_64BIT_DATA
+# define NC_FORMAT_64BIT_DATA	NC_FORMAT_CDF5
+#endif
+
 /* Some netCDF3 stubs for netCDF4 routines need netCDF4-only return codes
    These netCDF4 tokens are never defined in netCDF3-only netcdf.h */
 #ifndef HAVE_NETCDF4_H
@@ -221,16 +234,19 @@ char * /* O [sng] netCDF-compatible name */
 nm2sng_nc /* [fnc] Turn group/variable/dimension/attribute name into legal netCDF */
 (const char * const nm_sng); /* I [sng] Name to netCDF-ize */
 
-#if 0
-#ifdef HAVE_NETCDF4_H
+#ifdef ENABLE_MPI
+# ifdef HAVE_NETCDF4_H
 /* netCDF4 routines defined by Unidata netCDF4 Library libnetcdf.a */
-int nco_open_par(const char * const fl_nm,const int mode,MPI_Comm mpi_cmm,MPI_Info mpi_nfo,int * const nc_id);
-#endif /* !HAVE_NETCDF4_H */
-#endif /* !0 */
-#ifdef ENABLE_PNETCDF
+int nco_create_par(const char * const fl_nm,const int cmode,MPI_Comm mpi_cmm,MPI_Info mpi_nfo,int * const nc_id);
+int nco_open_par  (const char * const fl_nm,const int  mode,MPI_Comm mpi_cmm,MPI_Info mpi_nfo,int * const nc_id);
+int nco_var_par_access(const int nc_id,const int var_id,const int par_access);
+# endif /* !HAVE_NETCDF4_H */
+# ifdef PNETCDF_EXPOSED_API
 /* pnetCDF routines defined by ANL Parallel netCDF Library libpnetcdf.a */
-int ncompi_open(MPI_Comm mpi_cmm,const char * const fl_nm,const int mode,MPI_Info mpi_nfo,int * const nc_id);
-#endif /* !ENABLE_PNETCDF */
+int ncompi_create(MPI_Comm mpi_cmm,const char * const fl_nm,const int cmode,MPI_Info mpi_nfo,int * const nc_id);
+int ncompi_open  (MPI_Comm mpi_cmm,const char * const fl_nm,const int omode,MPI_Info mpi_nfo,int * const nc_id);
+# endif /* !PNETCDF_EXPOSED_API */
+#endif /* !ENABLE_MPI */
 
 /* Begin file-level routines */
 int nco_create(const char * const fl_nm,const int cmode,int * const nc_id);
