@@ -1,10 +1,11 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_sng_utl.h,v 1.46 2014/04/14 04:54:12 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_sng_utl.h,v 1.48 2014/08/22 20:27:48 zender Exp $ */
 
 /* Purpose: String utilities */
 
 /* Copyright (C) 1995--2014 Charlie Zender
-   License: GNU General Public License (GPL) Version 3
-   See http://www.gnu.org/copyleft/gpl.html for full license text */
+   This file is part of NCO, the netCDF Operators. NCO is free software.
+   You can redistribute and/or modify NCO under the terms of the 
+   GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 /* Usage:
    #include "nco_sng_utl.h" *//* String utilities */
@@ -81,6 +82,10 @@ char * /* O [sng] CDL-compatible name */
 nm2sng_cdl /* [fnc] Turn variable/dimension/attribute name into legal CDL */
 (const char * const nm_sng); /* I [sng] Name to CDL-ize */
 
+char * /* O [sng] CDL-compatible name */
+nm2sng_fl /* [fnc] Turn file name into legal string for shell commands */
+(const char * const nm_sng); /* I [sng] Name to sanitize */
+
 char * /* O [sng] String containing printable result */
 chr2sng_cdl /* [fnc] Translate C language character to printable, visible ASCII bytes */
 (const char chr_val, /* I [chr] Character to process */
