@@ -1,15 +1,13 @@
-/* $Header: /cvsroot/nco/nco/src/nco/ncrename.c,v 1.193 2014/05/21 20:39:29 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/ncrename.c,v 1.198 2014/07/11 20:55:45 zender Exp $ */
 
 /* ncrename -- netCDF renaming operator */
 
 /* Purpose: Rename dimensions, variables, and attributes of a netCDF file */
 
 /* Copyright (C) 1995--2014 Charlie Zender
-
-   License: GNU General Public License (GPL) Version 3
-   The full license text is at http://www.gnu.org/copyleft/gpl.html 
-   and in the file nco/doc/LICENSE in the NCO source distribution.
-   
+   This file is part of NCO, the netCDF Operators. NCO is free software.
+   You can redistribute and/or modify NCO under the terms of the 
+   GNU General Public License (GPL) Version 3.
    As a special exception to the terms of the GPL, you are permitted 
    to link the NCO source code with the HDF, netCDF, OPeNDAP, and UDUnits
    libraries and to distribute the resulting executables under the terms 
@@ -58,8 +56,26 @@
 # endif /* !HAVE_GETOPT_H */ 
 #endif /* HAVE_GETOPT_LONG */
 
+#ifdef I18N
+# include <langinfo.h> /* nl_langinfo() */
+# include <libintl.h> /* Internationalization i18n */
+# include <locale.h> /* Locale setlocale() */
+# define _(sng) gettext (sng)
+# define gettext_noop(sng) (sng)
+# define N_(sng) gettext_noop(sng)
+#endif /* I18N */
+/* Supply stub gettext() function in case i18n failed */
+#ifndef _LIBINTL_H
+# define gettext(foo) foo
+#endif /* _LIBINTL_H */
+
 /* 3rd party vendors */	 
 #include <netcdf.h> /* netCDF definitions and C library */	 
+#ifdef ENABLE_MPI
+# include <mpi.h> /* MPI definitions */
+# include <netcdf_par.h> /* Parallel netCDF definitions */
+# include "nco_mpi.h" /* MPI utilities */
+#endif /* !ENABLE_MPI */
 
 /* #define MAIN_PROGRAM_FILE MUST precede #include libnco.h */
 #define MAIN_PROGRAM_FILE
@@ -100,8 +116,8 @@ main(int argc,char **argv)
 
   char var_nm[NC_MAX_NAME+1];
 
-  const char * const CVS_Id="$Id: ncrename.c,v 1.193 2014/05/21 20:39:29 zender Exp $"; 
-  const char * const CVS_Revision="$Revision: 1.193 $";
+  const char * const CVS_Id="$Id: ncrename.c,v 1.198 2014/07/11 20:55:45 zender Exp $"; 
+  const char * const CVS_Revision="$Revision: 1.198 $";
   const char * const opt_sht_lst="a:D:d:g:hl:Oo:p:rv:-:";
   const char dlm_chr='@'; /* Character delimiting variable from attribute name  */
   const char opt_chr='.'; /* Character indicating presence of following variable/dimension/attribute in file is optional */
@@ -137,6 +153,13 @@ main(int argc,char **argv)
 
   trv_tbl_sct *trv_tbl; /* [lst] Traversal table */
 
+#ifdef ENABLE_MPI
+  /* Declare all MPI-specific variables here */
+  MPI_Comm mpi_cmm=MPI_COMM_WORLD; /* [prc] Communicator */
+  int prc_rnk; /* [idx] Process rank */
+  int prc_nbr=0; /* [nbr] Number of MPI processes */
+#endif /* !ENABLE_MPI */
+  
   static struct option opt_lng[] =
   { /* Structure ordered by short option key if possible */
     /* Long options with no argument, no short option counterpart */
@@ -192,6 +215,14 @@ main(int argc,char **argv)
   /* Get program name and set program enum (e.g., nco_prg_id=ncra) */
   nco_prg_nm=nco_prg_prs(argv[0],&nco_prg_id);
 
+#ifdef ENABLE_MPI
+  /* MPI Initialization */
+  if(False) (void)fprintf(stdout,gettext("%s: WARNING Compiled with MPI\n"),nco_prg_nm);
+  MPI_Init(&argc,&argv);
+  MPI_Comm_size(mpi_cmm,&prc_nbr);
+  MPI_Comm_rank(mpi_cmm,&prc_rnk);
+#endif /* !ENABLE_MPI */
+  
   /* Parse command line arguments */
   while(1){
     /* getopt_long_only() allows one dash to prefix long options */
@@ -233,6 +264,7 @@ main(int argc,char **argv)
     case 'D': /* Debugging level. Default is 0. */
       nco_dbg_lvl=(unsigned short int)strtoul(optarg,&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
       if(*sng_cnv_rcd) nco_sng_cnv_err(optarg,"strtoul",sng_cnv_rcd);
+      nc_set_log_level(nco_dbg_lvl);
       break;
     case 'd': /* Copy argument for later processing */
       dmn_rnm_arg[nbr_dmn_rnm]=(char *)strdup(optarg);
@@ -446,15 +478,13 @@ main(int argc,char **argv)
       trv_obj=nco_obj_usr_sng(var_nm,trv_tbl,&is_opt);  
 
       /* If object is group, set NC_GLOBAL */
-      if(trv_obj && trv_obj->nco_typ == nco_obj_typ_grp){ 
-        var_id=NC_GLOBAL;
-      }
+      if(trv_obj && trv_obj->nco_typ == nco_obj_typ_grp) var_id=NC_GLOBAL;
 
       /* Object found that matches "var_nm" */
-      if (trv_obj || IS_GLB_GRP_ATT){
+      if(trv_obj || IS_GLB_GRP_ATT){
 
         /* If object found get group ID, else groud ID is root (cases of "global") */
-        if (trv_obj) (void)nco_inq_grp_full_ncid(nc_id,trv_obj->grp_nm_fll,&grp_id); else grp_id=nc_id;
+        if(trv_obj) (void)nco_inq_grp_full_ncid(nc_id,trv_obj->grp_nm_fll,&grp_id); else grp_id=nc_id;
 
         /* Get var_id of variable */
         if(IS_GLB_GRP_ATT){
@@ -473,9 +503,7 @@ main(int argc,char **argv)
           }else{ /* Variable name does not contain opt_chr so variable presence is required */
 
             /* Get ID only if object is variable (not group). NB: use relative name found */
-            if(trv_obj->nco_typ == nco_obj_typ_var){ 
-              rcd=nco_inq_varid(grp_id,trv_obj->nm,&var_id);
-            } /* Get ID only if object is variable (not group) */
+            if(trv_obj->nco_typ == nco_obj_typ_var) rcd=nco_inq_varid(grp_id,trv_obj->nm,&var_id);
 
           } /* end if */
         } /* !IS_GLB_GRP_ATT */
@@ -506,29 +534,22 @@ main(int argc,char **argv)
 
       } /* Match variable by name */
 
+    }else{ /* ...or rename attribute for all variables and groups... */
 
-    }else{ /* ...or rename attribute for all variables... */
-
-      /* Loop table */
       for(unsigned int idx_tbl=0;idx_tbl<trv_tbl->nbr;idx_tbl++){
         (void)nco_inq_grp_full_ncid(nc_id,trv_tbl->lst[idx_tbl].grp_nm_fll,&grp_id);
 
-        /* We are in NC_GLOBAL zone if group  */
-        if (trv_tbl->lst[idx_tbl].nco_typ == nco_obj_typ_grp){
-          var_id=NC_GLOBAL;
-        }else {
-          (void)nco_inq_varid(grp_id,trv_tbl->lst[idx_tbl].nm,&var_id);
-        }
+        if(trv_tbl->lst[idx_tbl].nco_typ == nco_obj_typ_grp) var_id=NC_GLOBAL; else (void)nco_inq_varid(grp_id,trv_tbl->lst[idx_tbl].nm,&var_id);
 
         if(att_rnm_lst[idx_att].old_nm[0] == opt_chr){
-          /* Rename attribute if variable contains attribute else do nothing */
+          /* Rename attribute if variable/group contains attribute else do nothing */
           rcd=nco_inq_attid_flg(grp_id,var_id,att_rnm_lst[idx_att].old_nm+1L,&att_rnm_lst[idx_att].id);
           if(rcd == NC_NOERR){
             (void)nco_rename_att(grp_id,var_id,att_rnm_lst[idx_att].old_nm+1L,att_rnm_lst[idx_att].new_nm);
             nbr_rnm++;
             /* Inform user which variable had attribute renamed */
             if(var_id > NC_GLOBAL){
-              if(nco_dbg_lvl >= nco_dbg_std) (void)fprintf(stdout,"%s: Renamed attribute \'%s\' to \'%s\' for variable \'%s\'\n",nco_prg_nm,att_rnm_lst[idx_att].old_nm+1L,att_rnm_lst[idx_att].new_nm,var_nm);
+              if(nco_dbg_lvl >= nco_dbg_std) (void)fprintf(stdout,"%s: Renamed attribute \'%s\' to \'%s\' for variable \'%s\'\n",nco_prg_nm,att_rnm_lst[idx_att].old_nm+1L,att_rnm_lst[idx_att].new_nm,trv_tbl->lst[idx_tbl].nm);
             }else{
               if(nco_dbg_lvl >= nco_dbg_std) (void)fprintf(stdout,"%s: Renamed global or group attribute \'%s\' to \'%s\'\n",nco_prg_nm,att_rnm_lst[idx_att].old_nm+1L,att_rnm_lst[idx_att].new_nm);
             } /* end else */
@@ -575,7 +596,7 @@ main(int argc,char **argv)
     } /* nbr_rnm */
   } /* end loop over attributes to rename */
 
-  /* Catenate timestamped command line to "history" global attribute */
+  /* Catenate time-stamped command line to "history" global attribute */
   if(HISTORY_APPEND) (void)nco_hst_att_cat(nc_id,cmd_ln);
 
 #ifdef _OPENMP
@@ -623,11 +644,15 @@ main(int argc,char **argv)
     (void)trv_tbl_free(trv_tbl);
   } /* !flg_cln */
 
+#ifdef ENABLE_MPI
+  MPI_Finalize();
+#endif /* !ENABLE_MPI */
+  
   /* End timer */ 
   ddra_info.tmr_flg=nco_tmr_end; /* [enm] Timer flag */
   rcd+=nco_ddra((char *)NULL,(char *)NULL,&ddra_info);
-
   if(rcd != NC_NOERR) nco_err_exit(rcd,"main");
+
   nco_exit_gracefully();
   return EXIT_SUCCESS;
 } /* end main() */
